@@ -350,18 +350,7 @@ public class Mint {
         try? packagePath.installPath.delete()
         try packagePath.installPath.mkpath()
 
-        for executable in executables {
-            let executablePath = packageCheckoutPath + ".build/release/\(executable)"
-            if !executablePath.exists {
-                throw MintError.invalidExecutable(executablePath.lastComponent)
-            }
-            let destinationPackagePath = PackagePath(path: packagesPath, package: package, executable: executable)
-            if verbose {
-                standardOut.print("Copying \(executablePath.string) to \(destinationPackagePath.executablePath)")
-            }
-            // copy using shell instead of FileManager via PathKit because it removes executable permissions on Linux
-            try Task.run("cp", executablePath.string, destinationPackagePath.executablePath.string)
-        }
+        try copyReleaseProduct(packagePath: packagePath, packageCheckoutPath: packageCheckoutPath)
 
         let resourcesFile = packageCheckoutPath + "Package.resources"
         if resourcesFile.exists {
@@ -400,6 +389,18 @@ public class Mint {
 
         return true
     }
+
+    private func copyReleaseProduct(packagePath: PackagePath, packageCheckoutPath: Path) throws {
+        let packageReleasePath = packageCheckoutPath + ".build/release"
+        if !packageReleasePath.exists {
+            throw MintError.invalidExecutable(packageReleasePath.string)
+        }
+        if verbose {
+            standardOut.print("Copying \(packageReleasePath.string) to \(packagePath.installPath)")
+        }
+        // copy using shell instead of FileManager via PathKit because it removes executable permissions on Linux
+        try Task.run(bash: "cp -R \(packageReleasePath.string)/* \(packagePath.installPath.string)")
+    }
     
     private func checkLinkPath() {
         if let path = ProcessInfo.processInfo.environment["PATH"], !path.contains(linkPath.string) {
